#!/bin/bash
set -e

if [ $# -lt 2 ]; then
    echo "Usage ./test install_folder hysop_folder [cache_dir]"
    exit 1
fi

if [ $# -gt 3 ]; then
    echo "Usage ./test install_folder hysop_folder [cache_dir]"
    exit 1
fi

if [ ! -d "$1" ]; then
    echo "Folder $1 does not exist."
    exit 1
fi

if [ ! -d "$2" ]; then
    echo "Folder $2 does not exist."
    exit 1
fi

INSTALL_DIR=$1
HYSOP_DIR=$2
if [ $# -eq 3 ]; then
    CACHE_DIR=$3
    HAS_CACHE_DIR=true
else
    HAS_CACHE_DIR=false
fi

if [ "$HAS_CACHE_DIR" = true ]; then
    if [ -d "$CACHE_DIR" ]; then
        echo "Cache directory '$CACHE_DIR' was found."
        mkdir -p /root/.cache
        cp -r $CACHE_DIR/* /root/.cache
    else
        echo "Cache directory '$CACHE_DIR' was not found."
        mkdir -p $CACHE_DIR
    fi
fi

export PYTHONPATH="$INSTALL_DIR/lib/python2.7/site-packages:$INSTALL_DIR:$PYTHONPATH"
export HYSOP_VERBOSE=0
export HYSOP_DEBUG=0
export HYSOP_PROFILE=0
export HYSOP_KERNEL_DEBUG=0
python -c 'import hysop; print hysop'

# long backend dependent tests are disabled for ci
#python "$HYSOP_DIR/backend/device/codegen/kernels/tests/test_directional_advection.py"
#python "$HYSOP_DIR/backend/device/codegen/kernels/tests/test_directional_remesh.py"

python "$HYSOP_DIR/core/arrays/tests/test_array.py"
python "$HYSOP_DIR/core/graph/tests/test_graph.py"
python "$HYSOP_DIR/fields/tests/test_fields.py"
$HYSOP_DIR/fields/tests/test_cartesian.sh
python "$HYSOP_DIR/numerics/tests/test_fft.py"
python "$HYSOP_DIR/operator/tests/test_analytic.py"
python "$HYSOP_DIR/operator/tests/test_transpose.py"
python "$HYSOP_DIR/operator/tests/test_fd_derivative.py"
python "$HYSOP_DIR/operator/tests/test_spectral_derivative.py"
python "$HYSOP_DIR/operator/tests/test_spectral_curl.py"
python "$HYSOP_DIR/operator/tests/test_diffusion.py"
python "$HYSOP_DIR/operator/tests/test_poisson.py"
python "$HYSOP_DIR/operator/tests/test_solenoidal_projection.py"
python "$HYSOP_DIR/operator/tests/test_poisson_curl.py"
python "$HYSOP_DIR/operator/tests/test_custom_symbolic.py"
python "$HYSOP_DIR/operator/tests/test_directional_advection.py"
python "$HYSOP_DIR/operator/tests/test_directional_diffusion.py"
python "$HYSOP_DIR/operator/tests/test_directional_stretching.py"

# If scales (fortran advection library) is installed
python -c "from hysop.f2hysop import scales2py as scales" && python "$HYSOP_DIR/operator/tests/test_scales_advection.py"
python -c "from hysop.f2hysop import scales2py as scales" && python "$HYSOP_DIR/operator/tests/test_bilevel_advection.py"

#export HYSOP_VERBOSE=1
#EXAMPLE_DIR="$HYSOP_DIR/../examples"
#EXAMPLE_OPTIONS='-cp default -maxit 2'
#python "$EXAMPLE_DIR/analytic/analytic.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/scalar_diffusion/scalar_diffusion.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/scalar_advection/scalar_advection.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/shear_layer/shear_layer.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/taylor_green/taylor_green.py" -impl python $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/taylor_green/taylor_green.py" -impl opencl $EXAMPLE_OPTIONS
#python -c "from hysop.f2hysop import scales2py as scales" && python "$EXAMPLE_DIR/taylor_green/taylor_green.py" -impl fortran $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/bubble/periodic_bubble.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/bubble/periodic_bubble_levelset.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/bubble/periodic_bubble_levelset_penalization.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/bubble/periodic_jet_levelset.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/particles_above_salt/particles_above_salt_periodic.py" $EXAMPLE_OPTIONS
#python "$EXAMPLE_DIR/particles_above_salt/particles_above_salt_symmetrized.py" $EXAMPLE_OPTIONS

if [ "$HAS_CACHE_DIR" = true ]; then
    cp -r /root/.cache/* $CACHE_DIR/
    find $CACHE_DIR -name '*.lock' -delete
fi

exit 0
